@@ -1,4 +1,4 @@
-from verify import get_errors_fails, mark_incomplete, mark_complete
+from .verify import get_errors_fails, mark_incomplete, mark_complete
 import os
 task1_id = 'c82f56aa-237b-49c6-ba48-67c67e80f569' # Create the class
 task2_id = 'f64ba6c9-f685-4c47-88a5-7503ada30b8d' # Create methods for running the checks
